var searchData=
[
  ['t_5fget_5fscope_0',['T_get_scope',['../t-test_8c.html#a9bd21040a06841e844ed079bfa6af73d',1,'T_get_scope(const char *const *const *desc, char *buf, size_t n, const size_t *second_indices):&#160;t-test.c'],['../test_8h.html#a9bd21040a06841e844ed079bfa6af73d',1,'T_get_scope(const char *const *const *desc, char *buf, size_t n, const size_t *second_indices):&#160;t-test.c']]],
  ['taskbdassign_1',['TaskBDAssign',['../bestcomm__api_8c.html#a4117e7e78d83c86e3430384f56004629',1,'TaskBDAssign(TaskId taskId, void *buffer0, void *buffer1, int size, uint32 bdFlags):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#a4117e7e78d83c86e3430384f56004629',1,'TaskBDAssign(TaskId taskId, void *buffer0, void *buffer1, int size, uint32 bdFlags):&#160;bestcomm_api.c']]],
  ['taskbdrelease_2',['TaskBDRelease',['../bestcomm__api_8c.html#adaf12022da391fada14f3a5621da86a3',1,'TaskBDRelease(TaskId taskId):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#adaf12022da391fada14f3a5621da86a3',1,'TaskBDRelease(TaskId taskId):&#160;bestcomm_api.c']]],
  ['taskbdreset_3',['TaskBDReset',['../bestcomm__api_8c.html#a3d74620a816775576cfa503865033827',1,'TaskBDReset(TaskId taskId):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#a3d74620a816775576cfa503865033827',1,'TaskBDReset(TaskId taskId):&#160;bestcomm_api.c']]],
  ['taskdebug_4',['TaskDebug',['../bestcomm__api_8c.html#a455957c637fde5586390764bbc17cbfd',1,'TaskDebug(TaskId taskId, TaskDebugParamSet_t *paramSet):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#a455957c637fde5586390764bbc17cbfd',1,'TaskDebug(TaskId taskId, TaskDebugParamSet_t *paramSet):&#160;bestcomm_api.c']]],
  ['tasksattachimage_5',['TasksAttachImage',['../bestcomm__api_8c.html#af0debe7b5957175c27dd80de6359d264',1,'TasksAttachImage(sdma_regs *sdma):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#af0debe7b5957175c27dd80de6359d264',1,'TasksAttachImage(sdma_regs *sdma):&#160;bestcomm_api.c']]],
  ['tasksinitapi_6',['TasksInitAPI',['../bestcomm__api_8c.html#ae914efa36122a772ac8ad8848ec0812a',1,'TasksInitAPI(uint8 *MBarRef):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#ae914efa36122a772ac8ad8848ec0812a',1,'TasksInitAPI(uint8 *MBarRef):&#160;bestcomm_api.c']]],
  ['tasksinitapi_5fvm_7',['TasksInitAPI_VM',['../bestcomm__api_8c.html#a218e71b4e0b0e6e1fdbda806bdf937f7',1,'TasksInitAPI_VM(uint8 *MBarRef, uint8 *MBarPhys):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#a218e71b4e0b0e6e1fdbda806bdf937f7',1,'TasksInitAPI_VM(uint8 *MBarRef, uint8 *MBarPhys):&#160;bestcomm_api.c']]],
  ['tasksloadimage_8',['TasksLoadImage',['../bestcomm__api_8h.html#a62dc500dc177e7beb3ea18bd488f08bd',1,'load_task.c']]],
  ['taskstart_9',['TaskStart',['../bestcomm__api_8c.html#a2b48145c6c0418944c8226075ba97e7a',1,'TaskStart(TaskId taskId, uint32 autoStartEnable, TaskId autoStartTask, uint32 intrEnable):&#160;bestcomm_api.c'],['../bestcomm__api_8h.html#a2b48145c6c0418944c8226075ba97e7a',1,'TaskStart(TaskId taskId, uint32 autoStartEnable, TaskId autoStartTask, uint32 intrEnable):&#160;bestcomm_api.c']]],
  ['taskstop_10',['TaskStop',['../bestcomm__api_8h.html#a50a0e8468075caefc2c8594375e095fd',1,'TaskStop(TaskId taskId):&#160;bestcomm_api.c'],['../bestcomm__api_8c.html#a50a0e8468075caefc2c8594375e095fd',1,'TaskStop(TaskId taskId):&#160;bestcomm_api.c']]],
  ['taskversion_11',['TaskVersion',['../bestcomm__api_8h.html#a461fcaf9041c02fa54cdd52bc200eea3',1,'TaskVersion(void):&#160;bestcomm_api.c'],['../bestcomm__api_8c.html#a461fcaf9041c02fa54cdd52bc200eea3',1,'TaskVersion(void):&#160;bestcomm_api.c']]],
  ['tc_5fconfigure_12',['TC_Configure',['../tc_8h.html#a4f65db5c58b90e03f0b358cb0385db43',1,'TC_Configure(Tc *pTc, uint32_t dwChannel, uint32_t dwMode):&#160;tc.c'],['../tc_8c.html#a4f65db5c58b90e03f0b358cb0385db43',1,'TC_Configure(Tc *pTc, uint32_t dwChannel, uint32_t dwMode):&#160;tc.c']]],
  ['tc_5ffindmckdivisor_13',['TC_FindMckDivisor',['../tc_8c.html#ab49a1357d43f97cfc7846ddef6c1b470',1,'TC_FindMckDivisor(uint32_t dwFreq, uint32_t dwMCk, uint32_t *dwDiv, uint32_t *dwTcClks, uint32_t dwBoardMCK):&#160;tc.c'],['../tc_8h.html#ab49a1357d43f97cfc7846ddef6c1b470',1,'TC_FindMckDivisor(uint32_t dwFreq, uint32_t dwMCk, uint32_t *dwDiv, uint32_t *dwTcClks, uint32_t dwBoardMCK):&#160;tc.c']]],
  ['tc_5fstart_14',['TC_Start',['../tc_8h.html#af895f2ccec86be21d6126d5d55a54db2',1,'TC_Start(Tc *pTc, uint32_t dwChannel):&#160;tc.c'],['../tc_8c.html#af895f2ccec86be21d6126d5d55a54db2',1,'TC_Start(Tc *pTc, uint32_t dwChannel):&#160;tc.c']]],
  ['tc_5fstop_15',['TC_Stop',['../tc_8c.html#a2e06b3996c83626aa426b09ba647e65d',1,'TC_Stop(Tc *pTc, uint32_t dwChannel):&#160;tc.c'],['../tc_8h.html#a2e06b3996c83626aa426b09ba647e65d',1,'TC_Stop(Tc *pTc, uint32_t dwChannel):&#160;tc.c']]],
  ['tempmon_5fdeinit_16',['TEMPMON_Deinit',['../group__tempmon.html#ga9300a134aeda04212a2e84d1ccdb3e4a',1,'TEMPMON_Deinit(TEMPMON_Type *base):&#160;fsl_tempmon.c'],['../group__tempmon.html#ga9300a134aeda04212a2e84d1ccdb3e4a',1,'TEMPMON_Deinit(TEMPMON_Type *base):&#160;fsl_tempmon.c']]],
  ['tempmon_5fgetcurrenttemperature_17',['TEMPMON_GetCurrentTemperature',['../group__tempmon.html#gafd97504a28d73d0ffbd8cd4c8f0810b8',1,'TEMPMON_GetCurrentTemperature(TEMPMON_Type *base):&#160;fsl_tempmon.c'],['../group__tempmon.html#gafd97504a28d73d0ffbd8cd4c8f0810b8',1,'TEMPMON_GetCurrentTemperature(TEMPMON_Type *base):&#160;fsl_tempmon.c']]],
  ['tempmon_5fgetdefaultconfig_18',['TEMPMON_GetDefaultConfig',['../group__tempmon.html#gad39681b64944bdc56124fc4dcd66a81e',1,'TEMPMON_GetDefaultConfig(tempmon_config_t *config):&#160;fsl_tempmon.c'],['../group__tempmon.html#gad39681b64944bdc56124fc4dcd66a81e',1,'TEMPMON_GetDefaultConfig(tempmon_config_t *config):&#160;fsl_tempmon.c']]],
  ['tempmon_5finit_19',['TEMPMON_Init',['../group__tempmon.html#gad74d3cd12c87cd031afefa47a40c4ffa',1,'TEMPMON_Init(TEMPMON_Type *base, const tempmon_config_t *config):&#160;fsl_tempmon.c'],['../group__tempmon.html#gad74d3cd12c87cd031afefa47a40c4ffa',1,'TEMPMON_Init(TEMPMON_Type *base, const tempmon_config_t *config):&#160;fsl_tempmon.c']]],
  ['tempmon_5fsettempalarm_20',['TEMPMON_SetTempAlarm',['../group__tempmon.html#gab78940fbc3cc7a3b8e3562a5981803ca',1,'TEMPMON_SetTempAlarm(TEMPMON_Type *base, int8_t tempVal, tempmon_alarm_mode alarmMode):&#160;fsl_tempmon.c'],['../group__tempmon.html#gab78940fbc3cc7a3b8e3562a5981803ca',1,'TEMPMON_SetTempAlarm(TEMPMON_Type *base, int8_t tempVal, tempmon_alarm_mode alarmMode):&#160;fsl_tempmon.c']]],
  ['tftp_5fclose_21',['tftp_close',['../group__RTEMSAPITFTPFS.html#ga04b3e55addf82adeac70e748558a72a3',1,'tftp_close(void *tftp_handle):&#160;tftpDriver.c'],['../group__RTEMSAPITFTPFS.html#ga04b3e55addf82adeac70e748558a72a3',1,'tftp_close(void *tftp_handle):&#160;tftpDriver.c']]],
  ['tftp_5finitialize_5fnet_5fconfig_22',['tftp_initialize_net_config',['../group__RTEMSAPITFTPFS.html#ga4d637d8e2257252e3f799551c4f79093',1,'tftp_initialize_net_config(tftp_net_config *config):&#160;tftpDriver.c'],['../group__RTEMSAPITFTPFS.html#ga4d637d8e2257252e3f799551c4f79093',1,'tftp_initialize_net_config(tftp_net_config *config):&#160;tftpDriver.c']]],
  ['tftp_5fopen_23',['tftp_open',['../group__RTEMSAPITFTPFS.html#gaf2677b77661c1b437bf76e3976649539',1,'tftp_open(const char *hostname, const char *path, bool is_for_reading, const tftp_net_config *config, void **tftp_handle):&#160;tftpDriver.c'],['../group__RTEMSAPITFTPFS.html#gaf2677b77661c1b437bf76e3976649539',1,'tftp_open(const char *hostname, const char *path, bool is_for_reading, const tftp_net_config *config, void **tftp_handle):&#160;tftpDriver.c']]],
  ['tftp_5fread_24',['tftp_read',['../group__RTEMSAPITFTPFS.html#gaed91439c77f1863d025788c9b6d84da7',1,'tftp_read(void *tftp_handle, void *buffer, size_t count):&#160;tftpDriver.c'],['../group__RTEMSAPITFTPFS.html#gaed91439c77f1863d025788c9b6d84da7',1,'tftp_read(void *tftp_handle, void *buffer, size_t count):&#160;tftpDriver.c']]],
  ['tftp_5fwrite_25',['tftp_write',['../group__RTEMSAPITFTPFS.html#ga1f6ae1219688758f8556c03ab08e04d4',1,'tftp_write(void *tftp_handle, const void *buffer, size_t count):&#160;tftpDriver.c'],['../group__RTEMSAPITFTPFS.html#ga1f6ae1219688758f8556c03ab08e04d4',1,'tftp_write(void *tftp_handle, const void *buffer, size_t count):&#160;tftpDriver.c']]],
  ['thread_26',['thread',['../classrtems_1_1thread_1_1thread.html#aed89437c3db0f1325a7f572abfc08064',1,'rtems::thread::thread::thread(A &amp;&amp;attr, F &amp;&amp;func, Args &amp;&amp;... args)'],['../classrtems_1_1thread_1_1thread.html#a0a9b351de047bc808fe74b2012c1e5ac',1,'rtems::thread::thread::thread(F &amp;&amp;func, Args &amp;&amp;... args)'],['../classrtems_1_1thread_1_1thread.html#a7164eee34022828a6fb2b0f5092fcc8a',1,'rtems::thread::thread::thread() noexcept=default']]],
  ['tim6_5fdac_5firqhandler_27',['TIM6_DAC_IRQHandler',['../stm32h7xx__hal__timebase__tim__template_8c.html#a0839a45f331c4c067939b9c4533bbf4d',1,'stm32h7xx_hal_timebase_tim_template.c']]],
  ['timecountertick_28',['TimecounterTick',['../group__RTEMSTestSuitesValidation.html#ga829c19832253598dcf6d7a6785708813',1,'TimecounterTick(void):&#160;tx-timecounter.c'],['../group__RTEMSTestSuitesValidation.html#ga829c19832253598dcf6d7a6785708813',1,'TimecounterTick(void):&#160;tx-timecounter.c']]],
  ['times_29',['times',['../____times_8c.html#a66fb094fc080538738d0ef7dcf96fb13',1,'__times.c']]],
  ['tmpsns_5fdeinit_30',['TMPSNS_Deinit',['../group__tempsensor.html#ga93237703e80fa60d70ed4508d1b3aadb',1,'TMPSNS_Deinit(TMPSNS_Type *base):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga93237703e80fa60d70ed4508d1b3aadb',1,'TMPSNS_Deinit(TMPSNS_Type *base):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fdisableinterrupt_31',['TMPSNS_DisableInterrupt',['../group__tempsensor.html#ga6974d54ee4e41325f4b4fbb72911899e',1,'TMPSNS_DisableInterrupt(TMPSNS_Type *base, uint32_t mask):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga6974d54ee4e41325f4b4fbb72911899e',1,'TMPSNS_DisableInterrupt(TMPSNS_Type *base, uint32_t mask):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fenableinterrupt_32',['TMPSNS_EnableInterrupt',['../group__tempsensor.html#gaa811156f865545b268e2021f29e8b2a4',1,'TMPSNS_EnableInterrupt(TMPSNS_Type *base, uint32_t mask):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#gaa811156f865545b268e2021f29e8b2a4',1,'TMPSNS_EnableInterrupt(TMPSNS_Type *base, uint32_t mask):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fgetcurrenttemperature_33',['TMPSNS_GetCurrentTemperature',['../group__tempsensor.html#ga0068226e481f233103a4048ee1d86515',1,'TMPSNS_GetCurrentTemperature(TMPSNS_Type *base):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga0068226e481f233103a4048ee1d86515',1,'TMPSNS_GetCurrentTemperature(TMPSNS_Type *base):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fgetdefaultconfig_34',['TMPSNS_GetDefaultConfig',['../group__tempsensor.html#ga225247c2ce1e6780fc02ea5dffc75496',1,'TMPSNS_GetDefaultConfig(tmpsns_config_t *config):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga225247c2ce1e6780fc02ea5dffc75496',1,'TMPSNS_GetDefaultConfig(tmpsns_config_t *config):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5finit_35',['TMPSNS_Init',['../group__tempsensor.html#gacfa0235216db97e822f1698fa945fff7',1,'TMPSNS_Init(TMPSNS_Type *base, const tmpsns_config_t *config):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#gacfa0235216db97e822f1698fa945fff7',1,'TMPSNS_Init(TMPSNS_Type *base, const tmpsns_config_t *config):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fsettempalarm_36',['TMPSNS_SetTempAlarm',['../group__tempsensor.html#ga8cadd42e168377f6995cec4150c377b7',1,'TMPSNS_SetTempAlarm(TMPSNS_Type *base, int32_t tempVal, tmpsns_alarm_mode_t alarmMode):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga8cadd42e168377f6995cec4150c377b7',1,'TMPSNS_SetTempAlarm(TMPSNS_Type *base, int32_t tempVal, tmpsns_alarm_mode_t alarmMode):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fstartmeasure_37',['TMPSNS_StartMeasure',['../group__tempsensor.html#ga867ba5fd2b1d4781ddef4f33d30d6251',1,'TMPSNS_StartMeasure(TMPSNS_Type *base):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga867ba5fd2b1d4781ddef4f33d30d6251',1,'TMPSNS_StartMeasure(TMPSNS_Type *base):&#160;fsl_tempsensor.c']]],
  ['tmpsns_5fstopmeasure_38',['TMPSNS_StopMeasure',['../group__tempsensor.html#ga031571a6533ae58039981d16ad855d57',1,'TMPSNS_StopMeasure(TMPSNS_Type *base):&#160;fsl_tempsensor.c'],['../group__tempsensor.html#ga031571a6533ae58039981d16ad855d57',1,'TMPSNS_StopMeasure(TMPSNS_Type *base):&#160;fsl_tempsensor.c']]],
  ['tms570_5fbsp_5fpin_5fclear_5ffunction_39',['tms570_bsp_pin_clear_function',['../tms570-pinmux_8h.html#ac225c1f6113c3a39dfe69324b07fa625',1,'tms570_bsp_pin_clear_function(int pin_num, int pin_fnc):&#160;pinmux.c'],['../pinmux_8c.html#ac225c1f6113c3a39dfe69324b07fa625',1,'tms570_bsp_pin_clear_function(int pin_num, int pin_fnc):&#160;pinmux.c']]],
  ['tms570_5fbsp_5fpin_5fconfig_5fone_40',['tms570_bsp_pin_config_one',['../tms570-pinmux_8h.html#a3f1fcae6177e90127dd1af7e9c93efe4',1,'tms570_bsp_pin_config_one(uint32_t pin_num_and_fnc):&#160;pinmux.c'],['../pinmux_8c.html#a3f1fcae6177e90127dd1af7e9c93efe4',1,'tms570_bsp_pin_config_one(uint32_t pin_num_and_fnc):&#160;pinmux.c']]],
  ['tms570_5fbsp_5fpin_5fset_5ffunction_41',['tms570_bsp_pin_set_function',['../tms570-pinmux_8h.html#a096924e434015941cae44dce897ea5ef',1,'tms570_bsp_pin_set_function(int pin_num, int pin_fnc):&#160;pinmux.c'],['../pinmux_8c.html#a096924e434015941cae44dce897ea5ef',1,'tms570_bsp_pin_set_function(int pin_num, int pin_fnc):&#160;pinmux.c']]],
  ['tms570_5fbsp_5fpinmmr_5fconfig_42',['tms570_bsp_pinmmr_config',['../tms570-pinmux_8h.html#a061d7b53280d6fc349a4157613712aef',1,'tms570_bsp_pinmmr_config(const uint32_t *pinmmr_values, int reg_start, int reg_count):&#160;pinmux.c'],['../pinmux_8c.html#a061d7b53280d6fc349a4157613712aef',1,'tms570_bsp_pinmmr_config(const uint32_t *pinmmr_values, int reg_start, int reg_count):&#160;pinmux.c']]],
  ['tms570_5fdisable_5fparity_43',['tms570_disable_parity',['../tms570__selftest_8h.html#adb06cbc592de4f38bd82e75e2a9251f2',1,'tms570_disable_parity(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#adb06cbc592de4f38bd82e75e2a9251f2',1,'tms570_disable_parity(void):&#160;tms570_selftest.c']]],
  ['tms570_5fefc_5fcheck_44',['tms570_efc_check',['../tms570__selftest_8h.html#afd959ec39d9ce0d6aedcb981fcafe068',1,'tms570_efc_check(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#afd959ec39d9ce0d6aedcb981fcafe068',1,'tms570_efc_check(void):&#160;tms570_selftest.c']]],
  ['tms570_5fefc_5fcheck_5fself_5ftest_45',['tms570_efc_check_self_test',['../tms570__selftest_8c.html#ae8189fb35808005c608dec5b8aa171c4',1,'tms570_efc_check_self_test(void):&#160;tms570_selftest.c'],['../tms570__selftest_8h.html#ae8189fb35808005c608dec5b8aa171c4',1,'tms570_efc_check_self_test(void):&#160;tms570_selftest.c']]],
  ['tms570_5fefc_5fself_5ftest_46',['tms570_efc_self_test',['../tms570__selftest_8h.html#ab3d01ca7d79f38d9eeeeb01173a8d59f',1,'tms570_efc_self_test(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#ab3d01ca7d79f38d9eeeeb01173a8d59f',1,'tms570_efc_self_test(void):&#160;tms570_selftest.c']]],
  ['tms570_5fefc_5fstuck_5fzero_47',['tms570_efc_stuck_zero',['../tms570__selftest_8h.html#a4d666d70519bd602f33df025fde0700e',1,'tms570_efc_stuck_zero(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a4d666d70519bd602f33df025fde0700e',1,'tms570_efc_stuck_zero(void):&#160;tms570_selftest.c']]],
  ['tms570_5femif_5fsdram_5finit_48',['tms570_emif_sdram_init',['../tms570__hwinit_8h.html#aa8bfd88d63105e9a1112c94b364af5c0',1,'tms570_emif_sdram_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-lc4357-hdk_8c.html#aa8bfd88d63105e9a1112c94b364af5c0',1,'tms570_emif_sdram_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-ls3137-hdk_8c.html#aa8bfd88d63105e9a1112c94b364af5c0',1,'tms570_emif_sdram_init(void):&#160;hwinit-ls3137-hdk.c']]],
  ['tms570_5fenable_5fparity_49',['tms570_enable_parity',['../tms570__selftest_8h.html#ac1fe105c53eca3b538e109e72a9dc932',1,'tms570_enable_parity(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#ac1fe105c53eca3b538e109e72a9dc932',1,'tms570_enable_parity(void):&#160;tms570_selftest.c']]],
  ['tms570_5fesm_5fchannel_5fsr_5fclear_50',['tms570_esm_channel_sr_clear',['../tms570__selftest_8h.html#ab74fa521293388b990454fa3a164633a',1,'tms570_esm_channel_sr_clear(unsigned grp, unsigned chan):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#ab74fa521293388b990454fa3a164633a',1,'tms570_esm_channel_sr_clear(unsigned grp, unsigned chan):&#160;tms570_selftest.c']]],
  ['tms570_5fesm_5fchannel_5fsr_5fget_51',['tms570_esm_channel_sr_get',['../tms570__selftest_8h.html#a0cef2f68ef9c7ae337615fb420b50cb6',1,'tms570_esm_channel_sr_get(unsigned grp, unsigned chan):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a0cef2f68ef9c7ae337615fb420b50cb6',1,'tms570_esm_channel_sr_get(unsigned grp, unsigned chan):&#160;tms570_selftest.c']]],
  ['tms570_5fesm_5finit_52',['tms570_esm_init',['../tms570__hwinit_8h.html#a1d8af92ab5c4586aa17c0bea791b9efe',1,'tms570_esm_init(void):&#160;init_esm.c'],['../init__esm_8c.html#a1d8af92ab5c4586aa17c0bea791b9efe',1,'tms570_esm_init(void):&#160;init_esm.c']]],
  ['tms570_5fflash_5finit_53',['tms570_flash_init',['../tms570__hwinit_8h.html#a93991a2136c7abc0b1c6be56b46bd1dd',1,'tms570_flash_init(void):&#160;init_system.c'],['../init__system_8c.html#a93991a2136c7abc0b1c6be56b46bd1dd',1,'tms570_flash_init(void):&#160;init_system.c']]],
  ['tms570_5firq_5fget_5fpriority_54',['tms570_irq_get_priority',['../bsps_2arm_2tms570_2include_2bsp_2irq_8h.html#a3bc59ad8ec331be8782f97e882f6a5e2',1,'irq.h']]],
  ['tms570_5firq_5fset_5fpriority_55',['tms570_irq_set_priority',['../bsps_2arm_2tms570_2include_2bsp_2irq_8h.html#a706aa233309927420b72a4a1bbaa8146',1,'tms570_irq_set_priority(rtems_vector_number vector, uint32_t priority):&#160;irq.c'],['../bsps_2arm_2tms570_2irq_2irq_8c.html#a706aa233309927420b72a4a1bbaa8146',1,'tms570_irq_set_priority(rtems_vector_number vector, uint32_t priority):&#160;irq.c']]],
  ['tms570_5fmap_5fclock_5finit_56',['tms570_map_clock_init',['../tms570__hwinit_8h.html#a6843c9d8e672b736a060ea5314bd2c91',1,'tms570_map_clock_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-lc4357-hdk_8c.html#a6843c9d8e672b736a060ea5314bd2c91',1,'tms570_map_clock_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-ls3137-hdk_8c.html#a6843c9d8e672b736a060ea5314bd2c91',1,'tms570_map_clock_init(void):&#160;hwinit-ls3137-hdk.c']]],
  ['tms570_5fpbist_5ffail_57',['tms570_pbist_fail',['../tms570__selftest_8h.html#a3af264550de13cdb92997bdf563e9608',1,'tms570_pbist_fail(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a3af264550de13cdb92997bdf563e9608',1,'tms570_pbist_fail(void):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5fis_5ftest_5fcompleted_58',['tms570_pbist_is_test_completed',['../tms570__selftest_8h.html#af1c3d98396d0f295ab496cdc0577bd35',1,'tms570_pbist_is_test_completed(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#af1c3d98396d0f295ab496cdc0577bd35',1,'tms570_pbist_is_test_completed(void):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5fis_5ftest_5fpassed_59',['tms570_pbist_is_test_passed',['../tms570__selftest_8h.html#a3d0fcf098db785473095cdb41233f1a5',1,'tms570_pbist_is_test_passed(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a3d0fcf098db785473095cdb41233f1a5',1,'tms570_pbist_is_test_passed(void):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5fport_5ftest_5fstatus_60',['tms570_pbist_port_test_status',['../tms570__selftest_8h.html#a4b1c93384127a551a362cb3b5e177612',1,'tms570_pbist_port_test_status(uint32_t port):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a4b1c93384127a551a362cb3b5e177612',1,'tms570_pbist_port_test_status(uint32_t port):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5frun_61',['tms570_pbist_run',['../tms570__selftest_8h.html#a2376e5b0a51e86ba1f63df1bbada21ae',1,'tms570_pbist_run(uint32_t raminfoL, uint32_t algomask):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a2376e5b0a51e86ba1f63df1bbada21ae',1,'tms570_pbist_run(uint32_t raminfoL, uint32_t algomask):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5frun_5fand_5fcheck_62',['tms570_pbist_run_and_check',['../tms570__selftest_8h.html#a7103db3c0141d22f777ff513ffeb8658',1,'tms570_pbist_run_and_check(uint32_t raminfoL, uint32_t algomask):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a7103db3c0141d22f777ff513ffeb8658',1,'tms570_pbist_run_and_check(uint32_t raminfoL, uint32_t algomask):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5fself_5fcheck_63',['tms570_pbist_self_check',['../tms570__selftest_8h.html#a1918892570812dab64902cec171d51c7',1,'tms570_pbist_self_check(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#a1918892570812dab64902cec171d51c7',1,'tms570_pbist_self_check(void):&#160;tms570_selftest.c']]],
  ['tms570_5fpbist_5fstop_64',['tms570_pbist_stop',['../tms570__selftest_8h.html#ac5cc973602c5b073b3440d9ecc5baea3',1,'tms570_pbist_stop(void):&#160;tms570_selftest.c'],['../tms570__selftest_8c.html#ac5cc973602c5b073b3440d9ecc5baea3',1,'tms570_pbist_stop(void):&#160;tms570_selftest.c']]],
  ['tms570_5fperiph_5finit_65',['tms570_periph_init',['../tms570__hwinit_8h.html#ae309cda1599147b5dbdec6c4d19732b6',1,'tms570_periph_init(void):&#160;init_system.c'],['../init__system_8c.html#ae309cda1599147b5dbdec6c4d19732b6',1,'tms570_periph_init(void):&#160;init_system.c']]],
  ['tms570_5fpin_5fconfig_5fapply_66',['tms570_pin_config_apply',['../tms570-pinmux_8h.html#a3f9ad6598027b93d0d2c196c4ff5d9be',1,'tms570_pin_config_apply(uint32_t config):&#160;pinmux.c'],['../pinmux_8c.html#a3f9ad6598027b93d0d2c196c4ff5d9be',1,'tms570_pin_config_apply(uint32_t config):&#160;pinmux.c']]],
  ['tms570_5fpin_5fconfig_5farray_5fapply_67',['tms570_pin_config_array_apply',['../tms570-pinmux_8h.html#a3498fd82d80e88165b6d8e3d69f96c58',1,'tms570_pin_config_array_apply(const uint32_t *config, size_t count):&#160;pinmux.c'],['../pinmux_8c.html#a3498fd82d80e88165b6d8e3d69f96c58',1,'tms570_pin_config_array_apply(const uint32_t *config, size_t count):&#160;pinmux.c']]],
  ['tms570_5fpin_5fconfig_5fcomplete_68',['tms570_pin_config_complete',['../tms570-pinmux_8h.html#a6635d172fcd6c4225de0efc581c111c8',1,'tms570_pin_config_complete(void):&#160;pinmux.c'],['../pinmux_8c.html#a6635d172fcd6c4225de0efc581c111c8',1,'tms570_pin_config_complete(void):&#160;pinmux.c']]],
  ['tms570_5fpin_5fconfig_5fprepare_69',['tms570_pin_config_prepare',['../tms570-pinmux_8h.html#aacc9f0acaeb2fd30aa603a66cc6bb8ba',1,'tms570_pin_config_prepare(void):&#160;pinmux.c'],['../pinmux_8c.html#aacc9f0acaeb2fd30aa603a66cc6bb8ba',1,'tms570_pin_config_prepare(void):&#160;pinmux.c']]],
  ['tms570_5fpinmux_5finit_70',['tms570_pinmux_init',['../tms570__hwinit_8h.html#a42616a5455eebfb4efa9bfc67e4dfdf7',1,'tms570_pinmux_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-lc4357-hdk_8c.html#a42616a5455eebfb4efa9bfc67e4dfdf7',1,'tms570_pinmux_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-ls3137-hdk_8c.html#a42616a5455eebfb4efa9bfc67e4dfdf7',1,'tms570_pinmux_init(void):&#160;hwinit-ls3137-hdk.c']]],
  ['tms570_5fpll_5finit_71',['tms570_pll_init',['../tms570__hwinit_8h.html#a43137f0b9b1e10251be70ee40935709a',1,'tms570_pll_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-lc4357-hdk_8c.html#a43137f0b9b1e10251be70ee40935709a',1,'tms570_pll_init(void):&#160;hwinit-lc4357-hdk.c'],['../hwinit-ls3137-hdk_8c.html#a43137f0b9b1e10251be70ee40935709a',1,'tms570_pll_init(void):&#160;hwinit-ls3137-hdk.c']]],
  ['tms570_5fpom_5finitialize_5fand_5fclear_72',['tms570_pom_initialize_and_clear',['../tms570-pom_8h.html#af698d43ce55259177aa04dd0a4546fa9',1,'tms570_pom_initialize_and_clear(void):&#160;tms570-pom.c'],['../tms570-pom_8c.html#af698d43ce55259177aa04dd0a4546fa9',1,'tms570_pom_initialize_and_clear(void):&#160;tms570-pom.c']]],
  ['tms570_5fpom_5fremap_73',['tms570_pom_remap',['../tms570-pom_8h.html#aa5484712012d1e84f9422450a76fd6d4',1,'tms570_pom_remap(void):&#160;tms570-pom.c'],['../tms570-pom_8c.html#aa5484712012d1e84f9422450a76fd6d4',1,'tms570_pom_remap(void):&#160;tms570-pom.c']]],
  ['tms570_5fsci_5fset_5fattributes_74',['tms570_sci_set_attributes',['../tms570-sci_8c.html#a7cf94e3b205d7a61b8455d806ad96b67',1,'tms570_sci_set_attributes(rtems_termios_device_context *base, const struct termios *t):&#160;tms570-sci.c'],['../tms570-sci-driver_8h.html#a73848a263fd0b87c4ab8f1e151239fc5',1,'tms570_sci_set_attributes(rtems_termios_device_context *base, const struct termios *term):&#160;tms570-sci.c']]],
  ['tms570_5fselftest_5fpar_5fcheck_5fcan_75',['tms570_selftest_par_check_can',['../tms570__selftest__parity_8h.html#ab50449340fe25d5386816b58af2cd7b9',1,'tms570_selftest_par_check_can(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_can.c'],['../tms570__selftest__par__can_8c.html#ab50449340fe25d5386816b58af2cd7b9',1,'tms570_selftest_par_check_can(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_can.c']]],
  ['tms570_5fselftest_5fpar_5fcheck_5fmibspi_76',['tms570_selftest_par_check_mibspi',['../tms570__selftest__parity_8h.html#ac0478e6ffc00a10093eed29febc6bf61',1,'tms570_selftest_par_check_mibspi(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_mibspi.c'],['../tms570__selftest__par__mibspi_8c.html#ac0478e6ffc00a10093eed29febc6bf61',1,'tms570_selftest_par_check_mibspi(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_mibspi.c']]],
  ['tms570_5fselftest_5fpar_5fcheck_5fstd_77',['tms570_selftest_par_check_std',['../tms570__selftest__parity_8h.html#a214d12ffcd050f636d0c1c1b46ffdd61',1,'tms570_selftest_par_check_std(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_std.c'],['../tms570__selftest__par__std_8c.html#a214d12ffcd050f636d0c1c1b46ffdd61',1,'tms570_selftest_par_check_std(const tms570_selftest_par_desc_t *desc):&#160;tms570_selftest_par_std.c']]],
  ['tms570_5fselftest_5fpar_5frun_78',['tms570_selftest_par_run',['../tms570__selftest__parity_8h.html#a6d2f4eef57a7d66965b5b73ab6f0775f',1,'tms570_selftest_par_run(const tms570_selftest_par_desc_t *const *desc_arr, int desc_cnt):&#160;tms570_selftest_parity.c'],['../tms570__selftest__parity_8c.html#a6d2f4eef57a7d66965b5b73ab6f0775f',1,'tms570_selftest_par_run(const tms570_selftest_par_desc_t *const *desc_arr, int desc_cnt):&#160;tms570_selftest_parity.c']]],
  ['tms570_5fsystem_5fhw_5finit_79',['tms570_system_hw_init',['../tms570__hwinit_8h.html#adfc60d117ea095a205722a96aeaf3b65',1,'tms570_system_hw_init(void):&#160;init_system.c'],['../init__system_8c.html#adfc60d117ea095a205722a96aeaf3b65',1,'tms570_system_hw_init(void):&#160;init_system.c']]],
  ['tms570_5ftrim_5flpo_5finit_80',['tms570_trim_lpo_init',['../tms570__hwinit_8h.html#a788b6e4333764ce64557748a795fcaef',1,'tms570_trim_lpo_init(void):&#160;init_system.c'],['../init__system_8c.html#a788b6e4333764ce64557748a795fcaef',1,'tms570_trim_lpo_init(void):&#160;init_system.c']]],
  ['trng_5fdisable_81',['TRNG_Disable',['../trng_8c.html#abef9b87a924ee53111c78269dcde0281',1,'trng.c']]],
  ['trng_5fdisableit_82',['TRNG_DisableIt',['../trng_8c.html#a60faebbf3bfe3f4a9efd0b1e8d3d177b',1,'trng.c']]],
  ['trng_5fenable_83',['TRNG_Enable',['../trng_8c.html#abeb3609e1c787c2077b8c919d055ccee',1,'trng.c']]],
  ['trng_5fenableit_84',['TRNG_EnableIt',['../trng_8c.html#af96e24c24737b834f3dbb232ed043f13',1,'trng.c']]],
  ['trng_5fgetranddata_85',['TRNG_GetRandData',['../trng_8c.html#afcbb6fe55bfe5b04f3a98a3895a6c917',1,'trng.c']]],
  ['trng_5fgetstatus_86',['TRNG_GetStatus',['../trng_8c.html#a27dbe1eaaab132fbc547bfc53c3b2cd3',1,'trng.c']]],
  ['truncate_87',['truncate',['../truncate_8c.html#a87674838dd2bcf61e1a1fb5c9892ab6c',1,'truncate.c']]],
  ['try_5fget_5fprop_5ffrom_5fdevice_5ftree_88',['try_get_prop_from_device_tree',['../microblaze-fdt-support_8h.html#a17a20065d0beb20bcb34938b184e0517',1,'microblaze-fdt-support.c']]],
  ['tty1_5finitialize_89',['tty1_initialize',['../group__i386__tty.html#ga9849440de837696ce9155a063d69db5b',1,'tty1_initialize(rtems_device_major_number, rtems_device_minor_number, void *):&#160;tty_drv.c'],['../group__i386__tty.html#ga9849440de837696ce9155a063d69db5b',1,'tty1_initialize(rtems_device_major_number major, rtems_device_minor_number minor, void *arg):&#160;tty_drv.c']]],
  ['tty2_5finitialize_90',['tty2_initialize',['../group__i386__tty.html#gaf1727fd0bd4c6e3fb1cd040b753f09dc',1,'tty2_initialize(rtems_device_major_number, rtems_device_minor_number, void *):&#160;tty_drv.c'],['../group__i386__tty.html#gaf1727fd0bd4c6e3fb1cd040b753f09dc',1,'tty2_initialize(rtems_device_major_number major, rtems_device_minor_number minor, void *arg):&#160;tty_drv.c']]],
  ['tty_5fclose_91',['tty_close',['../group__i386__tty.html#ga10756309126cd53d00dea24f17888f9d',1,'tty_close(rtems_device_major_number, rtems_device_minor_number, void *):&#160;tty_drv.c'],['../group__i386__tty.html#ga10756309126cd53d00dea24f17888f9d',1,'tty_close(rtems_device_major_number major, rtems_device_minor_number minor, void *arg):&#160;tty_drv.c']]],
  ['twi_5fbytereceived_92',['TWI_ByteReceived',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a2bb399b4984df2fdaabf741326636de2',1,'TWI_ByteReceived(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a2bb399b4984df2fdaabf741326636de2',1,'TWI_ByteReceived(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fbytesent_93',['TWI_ByteSent',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a908535df2873ebeaa63f6fda73ea6708',1,'TWI_ByteSent(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a908535df2873ebeaa63f6fda73ea6708',1,'TWI_ByteSent(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fconfiguremaster_94',['TWI_ConfigureMaster',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a3777e57c07461a0fa56534213dd33215',1,'TWI_ConfigureMaster(Twihs *pTwi, uint32_t dwTwCk, uint32_t dwMCk):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ac90d2f32c99191c21f02626a9584b6bb',1,'TWI_ConfigureMaster(Twihs *pTwi, uint32_t twck, uint32_t mck):&#160;twi.c']]],
  ['twi_5fconfigureslave_95',['TWI_ConfigureSlave',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#adf540599d435de6b06ddc35427a17fed',1,'TWI_ConfigureSlave(Twihs *pTwi, uint8_t slaveAddress):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#adf540599d435de6b06ddc35427a17fed',1,'TWI_ConfigureSlave(Twihs *pTwi, uint8_t slaveAddress):&#160;twi.c']]],
  ['twi_5fdisableit_96',['TWI_DisableIt',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#ac976e61b9b9d4488753f960d3df80c63',1,'TWI_DisableIt(Twihs *pTwi, uint32_t sources):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ac976e61b9b9d4488753f960d3df80c63',1,'TWI_DisableIt(Twihs *pTwi, uint32_t sources):&#160;twi.c']]],
  ['twi_5fenableit_97',['TWI_EnableIt',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#ab3bf1b5df694229af5fae34ca569ab7b',1,'TWI_EnableIt(Twihs *pTwi, uint32_t sources):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ab3bf1b5df694229af5fae34ca569ab7b',1,'TWI_EnableIt(Twihs *pTwi, uint32_t sources):&#160;twi.c']]],
  ['twi_5fgetmaskedstatus_98',['TWI_GetMaskedStatus',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#aee8c3520f24c54aedbad6cee6ab2eeaa',1,'TWI_GetMaskedStatus(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#aee8c3520f24c54aedbad6cee6ab2eeaa',1,'TWI_GetMaskedStatus(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fgetstatus_99',['TWI_GetStatus',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a316b5d5ffbfa49a8d6517a061b92a4a6',1,'TWI_GetStatus(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a316b5d5ffbfa49a8d6517a061b92a4a6',1,'TWI_GetStatus(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5freadbyte_100',['TWI_ReadByte',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a8b4e96e6ce1126921517147b048fde51',1,'TWI_ReadByte(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a8b4e96e6ce1126921517147b048fde51',1,'TWI_ReadByte(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fsendstopcondition_101',['TWI_SendSTOPCondition',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#ade1813a089ae27dac920fa1b07d46b94',1,'TWI_SendSTOPCondition(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ade1813a089ae27dac920fa1b07d46b94',1,'TWI_SendSTOPCondition(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fstartread_102',['TWI_StartRead',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a806d1ace472ce5f4e2fe2de6f5a425ff',1,'TWI_StartRead(Twihs *pTwi, uint8_t address, uint32_t iaddress, uint8_t isize):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a806d1ace472ce5f4e2fe2de6f5a425ff',1,'TWI_StartRead(Twihs *pTwi, uint8_t address, uint32_t iaddress, uint8_t isize):&#160;twi.c']]],
  ['twi_5fstartwrite_103',['TWI_StartWrite',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a933fafb0a0d430f7feb10d01138b0466',1,'TWI_StartWrite(Twihs *pTwi, uint8_t address, uint32_t iaddress, uint8_t isize, uint8_t byte):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a933fafb0a0d430f7feb10d01138b0466',1,'TWI_StartWrite(Twihs *pTwi, uint8_t address, uint32_t iaddress, uint8_t isize, uint8_t byte):&#160;twi.c']]],
  ['twi_5fstop_104',['TWI_Stop',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#ab6f6a89c7dbb1075f904386273252977',1,'TWI_Stop(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ab6f6a89c7dbb1075f904386273252977',1,'TWI_Stop(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5ftransfercomplete_105',['TWI_TransferComplete',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#a8d8a0d10a7d128428c350f7337191fbd',1,'TWI_TransferComplete(Twihs *pTwi):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#a8d8a0d10a7d128428c350f7337191fbd',1,'TWI_TransferComplete(Twihs *pTwi):&#160;twi.c']]],
  ['twi_5fwritebyte_106',['TWI_WriteByte',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2twi_8c.html#ad728b448499f0b4d4633dfe0cc4a5ee7',1,'TWI_WriteByte(Twihs *pTwi, uint8_t byte):&#160;twi.c'],['../arm_2atsam_2include_2libchip_2include_2twi_8h.html#ad728b448499f0b4d4633dfe0cc4a5ee7',1,'TWI_WriteByte(Twihs *pTwi, uint8_t byte):&#160;twi.c']]]
];
